Revise JavaDoc for ClientFile and related classes.

Change-Id: I79009d58ee003860703dd26f6255b0b363ad8f8a
Signed-off-by: Tim Buschtöns <tbuschto@eclipsesource.com>
diff --git a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/dnd/ClientFileTransfer.java b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/dnd/ClientFileTransfer.java
index ec2bf30..e51d54a 100644
--- a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/dnd/ClientFileTransfer.java
+++ b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/dnd/ClientFileTransfer.java
@@ -11,15 +11,20 @@
 package org.eclipse.rap.rwt.dnd;
 
 import org.eclipse.rap.rwt.SingletonUtil;
+import org.eclipse.rap.rwt.client.ClientFile;
+import org.eclipse.rap.rwt.client.service.ClientFileUploader;
 import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.dnd.TransferData;
 
 
 /**
- * The class <code>ClientFileTransfer</code> provides a dedicated transfer type for RAP client files
- * DND operations.
+ * The class <code>ClientFileTransfer</code> allows the user to drop files from the user's file
+ * system on a <code>DropTarget</code>. The DropEvent will contain data of the type
+ * <code>ClientFile[]</code>.
  *
  * @see Transfer
+ * @see ClientFile
+ * @see ClientFileUploader
  * @since 2.3
  */
 public class ClientFileTransfer extends Transfer {
diff --git a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/ClientFile.java b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/ClientFile.java
index 1e4d685..0dbc7a6 100644
--- a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/ClientFile.java
+++ b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/ClientFile.java
@@ -10,25 +10,30 @@
  ******************************************************************************/
 package org.eclipse.rap.rwt.client;
 
+import org.eclipse.rap.rwt.client.service.ClientFileUploader;
+
 
 /**
- * Represents a file on the client
+ * Represents a file on the client.
  *
+ * @see ClientFileUploader
  * @since 2.3
  */
 public interface ClientFile {
 
   /**
-   * The name of the file as it is known to the client, without path information.
+   * The name of the file on the client, without path information. If the client can not
+   * determine the file name the string will be empty.
    *
-   * @return the file name as a string. May be empty, but never null.
+   * @return the file name as a string. May be empty, but never <code>null</code>.
    */
   String getName();
 
   /**
    * The string in lower case representing the MIME type of the File.
    *
-   * @return the type of the file or an empty string if the type is unknown. Is never null.
+   * @return the type of the file. May be empty, but never <code>null</code>.
    */
   String getType();
 
@@ -10,25 +10,30 @@
 
   /**
-   * The string in lower case representing the MIME type of the File.
+   * The string in lower case representing the MIME type of the file. If the client can not
+   * determine the file type the string will be empty.
    *
diff --git a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/service/ClientFileUploader.java b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/service/ClientFileUploader.java
index 4ed7c8d..8d929e9 100644
--- a/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/service/ClientFileUploader.java
+++ b/bundles/org.eclipse.rap.rwt/src/org/eclipse/rap/rwt/client/service/ClientFileUploader.java
@@ -11,6 +11,7 @@
 package org.eclipse.rap.rwt.client.service;
 
 import org.eclipse.rap.rwt.client.ClientFile;
+import org.eclipse.rap.rwt.dnd.ClientFileTransfer;
 
 /**
  * The ClientFileUploader service allows uploading client-side files to the server.
@@ -21,11 +22,12 @@
 public interface ClientFileUploader extends ClientService {
 
   /**
-   * Starts to upload the provided <code>ClientFile<code> to the given URL using HTTP POST. If no
-   * files has been provided, nothing happens.
+   * Starts to upload the provided <code>ClientFile</code> to the given URL using HTTP POST. If no
+   * files are provided, nothing happens.
    *
    * @param url the URL to upload to, must not be <code>null</code> or empty
    * @param clientFiles client-side files, must not be <code>null
    */
   public void submit( String url, ClientFile[] clientFiles );
 
@@ -21,11 +22,12 @@
    *
    * @param url the URL to upload to, must not be <code>null</code> or empty
-   * @param clientFiles client-side files, must not be <code>null
+   * @param clientFiles client-side files, must not be <code>null</code>
+   * @see ClientFileTransfer
    */
   public void submit( String url, ClientFile[] clientFiles );